@@ -3,16 +3,15 @@
 #define EIGEN_PERMANENTLY_DISABLE_STUPID_WARNINGS
 #include <RcppEigen.h>
 
-#include <iostream>
-#include <algorithm>
-#include <unordered_set>
-#include "sampler.h"
 #include "keyATMvb_main.h"
+#include "sampler.h"
+#include <algorithm>
+#include <iostream>
+#include <unordered_set>
 
 // [[Rcpp::plugins(cpp17)]]
 // [[Rcpp::depends(RcppEigen)]]
 
-
 using namespace Eigen;
 using namespace Rcpp;
 using namespace std;
@@ -23,8 +22,7 @@ using namespace std;
 //'
 //' @keywords internal
 // [[Rcpp::export]]
-List keyATMvb_call(List model)
-{
+List keyATMvb_call(List model) {
   keyATMvb keyATMvb_model(model);
   keyATMvb_model.fit();
   model = keyATMvb_model.return_model();
