@@ -3,35 +3,32 @@
 #define EIGEN_PERMANENTLY_DISABLE_STUPID_WARNINGS
 #include <RcppEigen.h>
 
-#include <iostream>
 #include <algorithm>
-#include <unordered_set>
+#include <iostream>
 #include <string>
+#include <unordered_set>
 
 // Sampler
 #include "sampler.h"
 
 // keyATM models
+#include "keyATM_HMM.h"
 #include "keyATM_base.h"
 #include "keyATM_cov.h"
 #include "keyATM_covPG.h"
-#include "keyATM_HMM.h"
 
 // Weighted LDA models
 #include "LDA_weight.h"
 #include "LDA_weightCov.h"
 #include "LDA_weightHMM.h"
 
-
 // [[Rcpp::plugins(cpp17)]]
 // [[Rcpp::depends(RcppEigen)]]
 
-
 using namespace Eigen;
 using namespace Rcpp;
 using namespace std;
 
-
 //' Run the Collapsed Gibbs sampler for the keyATM Base
 //'
 //' @param model A initialized model
@@ -39,8 +36,7 @@ using namespace std;
 //'
 //' @keywords internal
 // [[Rcpp::export]]
-List keyATM_fit_base(List model, bool resume = false)
-{
+List keyATM_fit_base(List model, bool resume = false) {
   keyATMbase keyATMbase_model(model);
   if (resume) {
     keyATMbase_model.resume_fit();
@@ -51,7 +47,6 @@ List keyATM_fit_base(List model, bool resume = false)
   return model;
 }
 
-
 //' Run the Collapsed Gibbs sampler for the keyATM covariates (Dir-Multi)
 //'
 //' @param model A initialized model
@@ -59,8 +54,7 @@ List keyATM_fit_base(List model, bool resume = false)
 //'
 //' @keywords internal
 // [[Rcpp::export]]
-List keyATM_fit_cov(List model, bool resume = false)
-{
+List keyATM_fit_cov(List model, bool resume = false) {
   keyATMcov keyATMcov_model(model);
   if (resume) {
     keyATMcov_model.resume_fit();
@@ -71,7 +65,6 @@ List keyATM_fit_cov(List model, bool resume = false)
   return model;
 }
 
-
 //' Run the Collapsed Gibbs sampler for the keyATM covariates (Polya-Gamma)
 //'
 //' @param model A initialized model
@@ -79,8 +72,7 @@ List keyATM_fit_cov(List model, bool resume = false)
 //'
 //' @keywords internal
 // [[Rcpp::export]]
-List keyATM_fit_covPG(List model, bool resume = false)
-{
+List keyATM_fit_covPG(List model, bool resume = false) {
   keyATMcovPG keyATMcov_modelPG(model);
   if (resume) {
     Rcout << "Resume is not supported for Polya-Gamma model" << endl;
@@ -91,7 +83,6 @@ List keyATM_fit_covPG(List model, bool resume = false)
   return model;
 }
 
-
 //' Run the Collapsed Gibbs sampler for the keyATM Dynamic
 //'
 //' @param model A initialized model
@@ -99,8 +90,7 @@ List keyATM_fit_covPG(List model, bool resume = false)
 //'
 //' @keywords internal
 // [[Rcpp::export]]
-List keyATM_fit_HMM(List model, bool resume = false)
-{
+List keyATM_fit_HMM(List model, bool resume = false) {
   keyATMhmm hmm_model(model);
   if (resume) {
     hmm_model.resume_fit();
@@ -111,7 +101,6 @@ List keyATM_fit_HMM(List model, bool resume = false)
   return model;
 }
 
-
 //' Run the Collapsed Gibbs sampler for weighted LDA
 //'
 //' @param model A initialized model
@@ -119,8 +108,7 @@ List keyATM_fit_HMM(List model, bool resume = false)
 //'
 //' @keywords internal
 // [[Rcpp::export]]
-List keyATM_fit_LDA(List model, bool resume = false)
-{
+List keyATM_fit_LDA(List model, bool resume = false) {
   LDAweight LDAweight_model(model);
   if (resume) {
     LDAweight_model.resume_fit();
@@ -131,7 +119,6 @@ List keyATM_fit_LDA(List model, bool resume = false)
   return model;
 }
 
-
 //' Run the Collapsed Gibbs sampler for weighted LDA with covariates
 //'
 //' @param model A initialized model
@@ -139,8 +126,7 @@ List keyATM_fit_LDA(List model, bool resume = false)
 //'
 //' @keywords internal
 // [[Rcpp::export]]
-List keyATM_fit_LDAcov(List model, bool resume = false)
-{
+List keyATM_fit_LDAcov(List model, bool resume = false) {
   LDAcov ldacov_model(model);
   if (resume) {
     ldacov_model.resume_fit();
@@ -151,7 +137,6 @@ List keyATM_fit_LDAcov(List model, bool resume = false)
   return model;
 }
 
-
 //' Run the Collapsed Gibbs sampler for the weighted LDA with HMM model
 //'
 //' @param model A initialized model
@@ -159,8 +144,7 @@ List keyATM_fit_LDAcov(List model, bool resume = false)
 //'
 //' @keywords internal
 // [[Rcpp::export]]
-List keyATM_fit_LDAHMM(List model, bool resume = false)
-{
+List keyATM_fit_LDAHMM(List model, bool resume = false) {
   LDAhmm ldahmm_model(model);
   if (resume) {
     ldahmm_model.resume_fit();
